open Format

let trace = ref None

let enable_trace arg =
  match arg with
    | None -> trace := Some stderr
    | Some filename ->
        let chan = open_out filename in
        trace := Some chan;
        at_exit (fun () -> close_out chan)

let () =
  Cmdline.register ~long:"trace" (Cmdline.Optional enable_trace)
    ~help:"print execution trace"

let print p ev =
  kfprintf begin fun fmt ->
    let s = flush_str_formatter () in
    match !trace with
      | None -> ()
      | Some chan ->
        Pos.print_range chan p;
        Printf.fprintf chan "[%s] %s.\n" ev s;
        flush chan
  end str_formatter
